@@ -1,12 +1,9 @@
 package circular::require;
-BEGIN {
-  $circular::require::AUTHORITY = 'cpan:DOY';
-}
-{
-  $circular::require::VERSION = '0.11';
-}
+our $AUTHORITY = 'cpan:DOY';
+$circular::require::VERSION = '0.12';
 use strict;
 use warnings;
+
 # ABSTRACT: detect circularity in use/require statements
 
 use 5.010;
@@ -83,13 +80,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 circular::require - detect circularity in use/require statements
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -192,7 +191,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Jesse Luehrs.
+This software is copyright (c) 2016 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
